@@ -17,7 +17,7 @@
 
 from collections import OrderedDict
 import logging
-import os.path
+import os
 import sys
 import tempfile
 import yaml
@@ -378,8 +378,14 @@ class TripleoInventory(object):
                 if var in inventory:
                     inventory[var]['vars'].update(value)
 
-        with open(inventory_file_path, 'w') as inventory_file:
+        # Atomic update as concurrent tripleoclient commands can call this
+        inventory_file_dir = os.path.dirname(inventory_file_path)
+        with tempfile.NamedTemporaryFile(
+                'w',
+                dir=inventory_file_dir,
+                delete=False) as inventory_file:
             yaml.dump(inventory, inventory_file, TemplateDumper)
+        os.rename(inventory_file.name, inventory_file_path)
 
 
 def generate_tripleo_ansible_inventory(heat, auth,
